@@ -26,7 +26,7 @@
 
 #include <cassert>
 
-#include "url-parser/url_parser.h"
+#include "urlparse.h"
 
 #include "shrpx_upstream.h"
 #include "shrpx_client_handler.h"
@@ -131,40 +131,39 @@ void downstream_wtimeoutcb(struct ev_loop *loop, ev_timer *w, int revents) {
 // upstream could be nullptr for unittests
 Downstream::Downstream(Upstream *upstream, MemchunkPool *mcpool,
                        int64_t stream_id)
-    : dlnext(nullptr),
-      dlprev(nullptr),
-      response_sent_body_length(0),
-      balloc_(1024, 1024),
-      req_(balloc_),
-      resp_(balloc_),
-      request_start_time_(std::chrono::high_resolution_clock::now()),
-      blocked_request_buf_(mcpool),
-      request_buf_(mcpool),
-      response_buf_(mcpool),
-      upstream_(upstream),
-      blocked_link_(nullptr),
-      addr_(nullptr),
-      num_retry_(0),
-      stream_id_(stream_id),
-      assoc_stream_id_(-1),
-      downstream_stream_id_(-1),
-      response_rst_stream_error_code_(NGHTTP2_NO_ERROR),
-      affinity_cookie_(0),
-      request_state_(DownstreamState::INITIAL),
-      response_state_(DownstreamState::INITIAL),
-      dispatch_state_(DispatchState::NONE),
-      upgraded_(false),
-      chunked_request_(false),
-      chunked_response_(false),
-      expect_final_response_(false),
-      request_pending_(false),
-      request_header_sent_(false),
-      accesslog_written_(false),
-      new_affinity_cookie_(false),
-      blocked_request_data_eof_(false),
-      expect_100_continue_(false),
-      stop_reading_(false) {
-
+  : dlnext(nullptr),
+    dlprev(nullptr),
+    response_sent_body_length(0),
+    balloc_(1024, 1024),
+    req_(balloc_),
+    resp_(balloc_),
+    request_start_time_(std::chrono::high_resolution_clock::now()),
+    blocked_request_buf_(mcpool),
+    request_buf_(mcpool),
+    response_buf_(mcpool),
+    upstream_(upstream),
+    blocked_link_(nullptr),
+    addr_(nullptr),
+    num_retry_(0),
+    stream_id_(stream_id),
+    assoc_stream_id_(-1),
+    downstream_stream_id_(-1),
+    response_rst_stream_error_code_(NGHTTP2_NO_ERROR),
+    affinity_cookie_(0),
+    request_state_(DownstreamState::INITIAL),
+    response_state_(DownstreamState::INITIAL),
+    dispatch_state_(DispatchState::NONE),
+    upgraded_(false),
+    chunked_request_(false),
+    chunked_response_(false),
+    expect_final_response_(false),
+    request_pending_(false),
+    request_header_sent_(false),
+    accesslog_written_(false),
+    new_affinity_cookie_(false),
+    blocked_request_data_eof_(false),
+    expect_100_continue_(false),
+    stop_reading_(false) {
   auto config = get_config();
   auto &httpconf = config->http;
 
@@ -247,7 +246,7 @@ Downstream::~Downstream() {
 }
 
 int Downstream::attach_downstream_connection(
-    std::unique_ptr<DownstreamConnection> dconn) {
+  std::unique_ptr<DownstreamConnection> dconn) {
   if (dconn->attach_downstream(this) != 0) {
     return -1;
   }
@@ -275,7 +274,7 @@ void Downstream::detach_downstream_connection() {
   auto handler = dconn_->get_client_handler();
 
   handler->pool_downstream_connection(
-      std::unique_ptr<DownstreamConnection>(dconn_.release()));
+    std::unique_ptr<DownstreamConnection>(dconn_.release()));
 }
 
 DownstreamConnection *Downstream::get_downstream_connection() {
@@ -489,7 +488,7 @@ void append_last_header_key(BlockAllocator &balloc, bool &key_prev, size_t &sum,
   sum += len;
   auto &item = headers.back();
   auto name =
-      realloc_concat_string_ref(balloc, item.name, StringRef{data, len});
+    realloc_concat_string_ref(balloc, item.name, StringRef{data, len});
 
   auto p = const_cast<uint8_t *>(name.byte());
   util::inp_strlower(p + name.size() - len, p + name.size());
@@ -507,7 +506,7 @@ void append_last_header_value(BlockAllocator &balloc, bool &key_prev,
   sum += len;
   auto &item = headers.back();
   item.value =
-      realloc_concat_string_ref(balloc, item.value, StringRef{data, len});
+    realloc_concat_string_ref(balloc, item.value, StringRef{data, len});
 }
 } // namespace
 
@@ -620,7 +619,7 @@ void FieldStore::erase_content_length_and_transfer_encoding() {
 }
 
 void Downstream::set_request_start_time(
-    std::chrono::high_resolution_clock::time_point time) {
+  std::chrono::high_resolution_clock::time_point time) {
   request_start_time_ = std::move(time);
 }
 
@@ -720,7 +719,7 @@ int Downstream::end_upload_data() {
 }
 
 void Downstream::rewrite_location_response_header(
-    const StringRef &upstream_scheme) {
+  const StringRef &upstream_scheme) {
   auto hd = resp_.fs.header(http2::HD_LOCATION);
   if (!hd) {
     return;
@@ -730,15 +729,15 @@ void Downstream::rewrite_location_response_header(
     return;
   }
 
-  http_parser_url u{};
-  auto rv = http_parser_parse_url(hd->value.data(), hd->value.size(), 0, &u);
+  urlparse_url u;
+  auto rv = urlparse_parse_url(hd->value.data(), hd->value.size(), 0, &u);
   if (rv != 0) {
     return;
   }
 
-  auto new_uri = http2::rewrite_location_uri(balloc_, hd->value, u,
-                                             request_downstream_host_,
-                                             req_.authority, upstream_scheme);
+  auto new_uri =
+    http2::rewrite_location_uri(balloc_, hd->value, u, request_downstream_host_,
+                                req_.authority, upstream_scheme);
 
   if (new_uri.empty()) {
     return;
@@ -838,7 +837,7 @@ void Downstream::check_upgrade_fulfilled_http1() {
 
       std::array<uint8_t, base64::encode_length(20)> accept_buf;
       auto expected =
-          http2::make_websocket_accept_token(accept_buf.data(), ws_key_);
+        http2::make_websocket_accept_token(accept_buf.data(), ws_key_);
 
       upgraded_ = !expected.empty() && expected == accept->value;
     } else {
@@ -890,7 +889,7 @@ void Downstream::inspect_http1_request() {
 
   auto expect = req_.fs.header(http2::HD_EXPECT);
   expect_100_continue_ =
-      expect && util::strieq(expect->value, "100-continue"_sr);
+    expect && util::strieq(expect->value, "100-continue"_sr);
 }
 
 void Downstream::inspect_http1_response() {
@@ -1175,7 +1174,7 @@ void Downstream::add_rcbuf(nghttp3_rcbuf *rcbuf) {
 #endif // ENABLE_HTTP3
 
 void Downstream::set_downstream_addr_group(
-    const std::shared_ptr<DownstreamAddrGroup> &group) {
+  const std::shared_ptr<DownstreamAddrGroup> &group) {
   group_ = group;
 }
 
